==> openwebbeans-web-1.1.3-sources.jar: org/apache/webbeans/web/failover/OwbProxyObjectInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.web.failover;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectStreamClass;

import javassist.util.proxy.ProxyObjectInputStream;

public class OwbProxyObjectInputStream extends ProxyObjectInputStream 
{
    public OwbProxyObjectInputStream(InputStream in) throws IOException 
    {
        super(in);
    }
    
    protected Class<?> resolveClass(ObjectStreamClass desc)
    throws IOException, ClassNotFoundException
    {
        String name = desc.getName();
        try 
        {
            return Class.forName(name, false, 
                Thread.currentThread().getContextClassLoader());
        } 
        catch (ClassNotFoundException ex) 
        {
            return super.resolveClass(desc);
        }
    }
}

==> openwebbeans-web-1.1.8-sources.jar: org/apache/webbeans/web/failover/OwbProxyObjectInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.web.failover;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectStreamClass;

import javassist.util.proxy.ProxyObjectInputStream;

public class OwbProxyObjectInputStream extends ProxyObjectInputStream
{
    public OwbProxyObjectInputStream(InputStream in) throws IOException
    {
        super(in);
    }

    @Override
    protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException
    {
        try
        {
            String name = desc.getName();

            return Class.forName(name, false, Thread.currentThread().getContextClassLoader());
        }
        catch (ClassNotFoundException ex)
        {
            return super.resolveClass(desc);
        }
    }
}
